@@ -7,6 +7,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"regexp"
 	"runtime"
 	"runtime/debug"
 	"sort"
@@ -20,7 +21,7 @@ import (
 )
 
 // Version indicates the version of the application
-var Version = "3.3.3"
+var Version = "3.3.4"
 
 // Flags set via the CLI which control how the output is displayed
 
@@ -75,7 +76,7 @@ var More = false
 // Cocomo toggles the COCOMO calculation
 var Cocomo = false
 
-// Print a more SLOCCount like COCOMO calculation
+// SLOCCountFormat prints a more SLOCCount like COCOMO calculation
 var SLOCCountFormat = false
 
 // CocomoProjectType allows the flipping between project types which impacts the calculation
@@ -105,6 +106,12 @@ var DisableCheckBinary = false
 // UlocMode toggles checking for binary files using NUL bytes
 var UlocMode = false
 
+// Percent toggles checking for binary files using NUL bytes
+var Percent = false
+
+// MaxMean toggles checking for binary files using NUL bytes
+var MaxMean = false
+
 // Dryness toggles checking for binary files using NUL bytes
 var Dryness = false
 
@@ -168,7 +175,7 @@ var AverageWage int64 = 56286
 // Overhead is the overhead multiplier for corporate overhead (facilities, equipment, accounting, etc.)
 var Overhead float64 = 2.4
 
-// the effort adjustment factor derived from the cost drivers, i.e. 1.0 if rated nominal
+// EAF is the effort adjustment factor derived from the cost drivers, i.e. 1.0 if rated nominal
 var EAF float64 = 1.0
 
 // GcFileCount is the number of files to process before turning the GC back on
@@ -593,6 +600,16 @@ func Process() {
 	fileWalker.IncludeHidden = true
 	fileWalker.ExcludeDirectory = PathDenyList
 
+	for _, exclude := range Exclude {
+		regexpResult, err := regexp.Compile(exclude)
+		if err == nil {
+			fileWalker.ExcludeFilenameRegex = append(fileWalker.ExcludeFilenameRegex, regexpResult)
+			fileWalker.ExcludeDirectoryRegex = append(fileWalker.ExcludeDirectoryRegex, regexpResult)
+		} else {
+			printError(err.Error())
+		}
+	}
+
 	go func() {
 		err := fileWalker.Start()
 		if err != nil {
